local BugReport = require("setting.BugReport")
local SettingLogic = require("setting.SettingLogic")

function CG_BUG_REPORT(human, msg)
	BugReport.bugReport(human, msg.type, msg.title, msg.content)
end

function CG_PLAYER_JUBAO(human, msg)
	BugReport.jubao(human, msg.targetUuid, msg.targetName, msg.code)
end

function CG_SETTING_SYSTEM(human, msg)
	SettingLogic.set(human, msg.flag)
end

function CG_FAQ_QUERY_BASE(human)
	SettingLogic.faqQueryBase(human)
end

function CG_FAQ_QUERY_DETAIL(human, msg)
	SettingLogic.faqQueryDetail(human, msg.id)
end

function CG_HELP_MISC_QUERY(human, msg)
	SettingLogic.helpMiscQuery(human, msg.id)
end

function CG_EXPLAIN_DETAIL(human, msg)
    SettingLogic.explainDetail(human, msg.id)
end

function CG_RESOURCE_QUERY(human, msg)
    SettingLogic.resourceQuery(human)
end

function CG_STRATEGY_QUERY(human,msg)
    SettingLogic.strategyQuery(human)
end

function CG_SETTING_SOUND(human, msg)
    SettingLogic.settingSound(human, msg.music, msg.acoustic, msg.voice)
end

function CG_SETTING_LANGUAGE(human, msg)
    SettingLogic.settingLang(human, msg.lang)
end